| mfnj | R Documentation |
A MultiFurcating version of the Neighbor-Joining method for reconstructing phylogenetic trees (Fernandez et al., 2023). Multifurcated phylogenetic trees can group more than two clusters when tied distances occur, and therefore they do not depend on the order of the input taxa.
mfnj(x, digits = NULL)
x |
A structure of class |
digits |
An integer value specifying the precision, i.e., the number of
significant decimal digits to be used for the comparisons between distances.
This is an important parameter, since equal distances at a certain precision
may become different by increasing its value. Thus, it may be responsible of
the existence of tied distances. If the value of this parameter is negative
or |
An object of class "mfnj" that describes the multifurcated phylogenetic
tree obtained. The object is a list with the following components:
call |
The call that produced the result. |
digits |
Number of significant decimal digits used as precision. It is given by the user or automatically set to the number of significant decimal digits in the input distances. |
size |
Number of taxa. |
labels |
Labels of the taxa. |
nwk |
A string describing the output phylogenetic tree in Newick format. |
polytomies |
Number of polytomies in the phylogenetic tree. |
Class "mfnj" has methods for the following generic functions:
print, summary and plot.
Alberto Fernandez alberto.fernandez@urv.cat and Sergio Gomez sergio.gomez@urv.cat.
Fernandez, A.; Segura-Alabart, N.; Serratosa, F. (2023). The MultiFurcating Neighbor-Joining algorithm for reconstructing polytomic phylogenetic trees. Journal of Molecular Evolution, 91, 773–779. <doi:10.1007/s00239-023-10134-z>.
Randi, E.; Gentile, L.; Boscagli, G.; Huber, D.; Roth, H.U. (1994). Mitochondrial DNA sequence divergence among some west European brown bear (Ursus arctos L.) populations. Lessons for conservation. Heredity, 73(5): 480–489. <doi:10.1038/hdy.1994.146>.
dist.
## Table 4 from Randi et al. (1994)
m <- matrix(0, 9, 9)
m[lower.tri(m)] <- c(1.3, 4.3, 4.3, 2.7, 3.0, 1.7, 2.0, 8.7,
4.3, 4.3, 2.3, 3.0, 1.7, 2.0, 8.0,
0.7, 5.0, 1.3, 2.7, 3.0, 10.0,
5.0, 1.3, 2.7, 3.0, 10.0,
3.7, 2.3, 2.7, 10.0,
2.0, 2.3, 8.7,
0.3, 9.0,
9.4)
x <- as.dist(m)
attr(x, "Labels") <- c("Abruzzo", "Pyrenees", "Kodiak", "Captive-3",
"Captive-4", "Captive-5", "Grizzly", "Polar-2", "Black")
## Reconstruct neighbor-joining phylogenetic tree
t <- mfnj(x, digits = 6)
summary(t)
plot(t)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.